import java.io.FileInputStream;

import java.security.Security;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import java.util.Date;
import java.util.Properties;

import oracle.jdbc.pool.OracleDataSource;

import oracle.security.pki.OraclePKIProvider;

public class JDBCSSLTester
{
  private static Properties dbprops = new Properties();
  private static Properties props = new Properties();

  private static OracleDataSource ods = null;

  public JDBCSSLTester()
  {
    Security.insertProviderAt(new OraclePKIProvider(), 3);
  }

  public void run()
    throws SQLException
  {
    String sql = "select user from dual";
    Statement stmt = null;
    ResultSet rset = null;
    Connection conn = null;

    try
    {
      conn = getConnection();
      stmt = conn.createStatement();
      rset = stmt.executeQuery(sql);
      rset.next();

      if (rset != null)
      {
        System.out.println(String.format("Conncted as DATABASE USER %s",
                                         rset.getString(1)));
      }
    }
    finally
    {
      if (stmt != null)
      {
        stmt.close();
      }

      if (rset != null)
      {
        rset.close();
      }

      if (conn != null)
      {
        conn.close();
      }
    }
  }

  public static Connection getConnection()
    throws SQLException
  {

    ods = new OracleDataSource();
    ods.setUser(dbprops.getProperty("dbuser"));
    ods.setPassword(dbprops.getProperty("dbpassword"));
    ods.setURL(dbprops.getProperty("dbURL"));
    ods.setConnectionProperties(props);

    Connection conn = ods.getConnection();

    return conn;
  }

  public static void main(String[] args)
  {
    System.out.println("Start: " + new Date());
    JDBCSSLTester testssl = new JDBCSSLTester();

    try
    {
      dbprops.load(new FileInputStream("db.properties"));
      props.load(new FileInputStream(args[0]));
      testssl.run();
    }
    catch (SQLException se)
    {
      System.out.println("SQL Exception occurred: ");
      se.printStackTrace();
    }
    catch (Exception e)
    {
      System.out.println("Exception occurred: ");
      e.printStackTrace();
    }

    System.out.println("Ended: " + new Date());
  }


}
